@@ -1,17 +1,19 @@
 package Text::CSV::Merge;
 {
-  $Text::CSV::Merge::VERSION = '0.04';
+  $Text::CSV::Merge::VERSION = '0.05';
 }
 # ABSTRACT: Fill in gaps in a CSV file from another CSV file
 
 use Modern::Perl '2010';
+use autodie;
+use utf8;
+
 use Moo 1.001000;
+use Carp;
 use IO::File;
 use Text::CSV_XS;
 use DBI; # for DBD::CSV
 use Log::Dispatch;
-use autodie;
-use utf8;
 
 
 has +logger => (
@@ -30,7 +32,7 @@ has +csv_parser => (
     is => 'lazy',
     builder => sub {
         Text::CSV_XS->new({ binary => 1, eol => $/ })
-            or die "Cannot use CSV: " . Text::CSV_XS->error_diag();
+            or croak("Cannot use module Text::CSV_XS: " . Text::CSV_XS->error_diag());
     }
 );
 
@@ -45,7 +47,7 @@ has +dbh => (
             # Better performance with XS
             csv_class => "Text::CSV_XS", 
             # csv_null => 1, 
-        }) or die "Cannot connect: $DBI::errstr";
+        }) or croak("Cannot connect to CSV file via DBI: $DBI::errstr");
     }
 );
 
@@ -57,7 +59,7 @@ has base_file => (
     #validate it
     #isa => sub {},
     coerce => sub {
-        my $base_fh = IO::File->new( $_[0], '<' ) or die "$_[0]: $!";
+        my $base_fh = IO::File->new( $_[0], '<' ) or croak("Open file: '$_[0]' failed: $!");
         $base_fh->binmode(":utf8");
         
         return $base_fh;
@@ -78,7 +80,7 @@ has output_file => (
     required => 0,
     default => 'merged_output.csv',
     coerce => sub {
-        my $output_fh = IO::File->new( $_[0], '>' ) or die "$_[0]: $!";
+        my $output_fh = IO::File->new( $_[0], '>' ) or croak("Open file: '$_[0]' failed: $!");
         $output_fh->binmode(":utf8");
         
         return $output_fh;
@@ -93,7 +95,8 @@ has columns=> (
 has search_field => (
     is => 'rw',
     required => 1,
-    init_arg => 'search'#,
+    init_arg => 'search'
+    #,
     #isa => sub {
         # validate that search_field is one of the columns in the base file
         #die "Search parameter: '$_[0]' is not one of the columns: @{$self->columns}";
@@ -107,22 +110,15 @@ has first_row_is_headers => (
     #validate it
     isa => sub {
         # @TODO: there's got to be a better way to do this!
-        die "Must be 1 or 0" unless ( $_[0] =~ /'1'|'0'/ || $_[0] == 1 || $_[0] == 0 );
+        croak("Option 'first_row_is_headers' must be 1 or 0") unless ( $_[0] =~ m{'1'|'0'}x || $_[0] == 1 || $_[0] == 0 );
     },
 );
 
-#=method BUILD
-#Constructor. 
-#=cut
-#sub BUILD {
-#    my $self = shift;
-#}
-
 sub merge {
     my $self = shift;
 
     # validate that search_field is one of the columns in the base file
-    die "Search parameter: '$self->search_field' is not one of the columns: @{$self->columns}"
+    croak("Search parameter: '$self->search_field' is not one of the columns: @{$self->columns}")
         unless ( scalar(grep { $_ eq $self->search_field } @{$self->columns}) );
         # Use scalar() to force grep to return the number of matches; 
         # 0 -> false for the 'unless' statement.
@@ -154,7 +150,7 @@ sub merge {
             # make a hash of arrays
             if ( @nulls  ) {
                 # search $merge_file for the missing data's row
-                $" = ','; # reset the list separator for array interpolation to suit SQL
+                local $" = ','; # reset the list separator for array interpolation to suit SQL
                 
                 # To get the original case for the columns, specify the column
                 # names rather than using SELECT *, since it normalizes to
@@ -162,7 +158,7 @@ sub merge {
                 # http://stackoverflow.com/questions/3350775/dbdcsv-returns-header-in-lower-case
                 my $sth = $self->dbh->prepare(
                     "select @{$self->columns} from $self->{merge_file} where $self->{search_field} = ?"
-                ) or die "Cannot prepare: " . $self->dbh->errstr ();
+                ) or croak("Cannot prepare DBI statement: " . $self->dbh->errstr ());
 
                 $sth->execute($row->{$self->search_field});
                 
@@ -204,6 +200,8 @@ sub merge {
     # Or, here I've switched to Text::CSV_XS's specific print_hr(), which 
     # is simply missing from the PP (Pure Perl) version.
     $self->csv_parser->print_hr($self->output_file, $_) for @rows;
+    
+    return 1;
 };
 
 sub DEMOLISH {
@@ -211,7 +209,9 @@ sub DEMOLISH {
 
     ## Clean up!
     $self->base_file->close();
-    $self->output_file->close() or die "output.csv: $!";
+    $self->output_file->close() or croak("Close 'output.csv' failed: $!");
+    
+    return;
 }
 
 
@@ -227,7 +227,7 @@ Text::CSV::Merge - Fill in gaps in a CSV file from another CSV file
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
